/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { IResource, Resource } from 'aws-cdk-lib';
import * as iam from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
/******************************************************************************
 *                              COMMON
 *****************************************************************************/
/**
 * Represents a Kendra Index, either created with CDK or imported.
 */
export interface IKendraGenAiIndex extends IResource {
    /**
     * The Amazon Resource Name (ARN) of the index.
     * @example 'arn:aws:kendra:us-east-1:123456789012:index/af04c7ea-22bc-46b7-a65e-6c21e604fc11'
     */
    readonly indexArn: string;
    /**
     * The identifier of the index.
     * @example 'af04c7ea-22bc-46b7-a65e-6c21e604fc11'.
     */
    readonly indexId: string;
    /**
     * An IAM role that gives Amazon Kendra permissions to access
     * your Amazon CloudWatch logs and metrics. This is also the
     * role used when you use the BatchPutDocument operation to index
     * documents from an Amazon S3 bucket.
     */
    readonly role: iam.IRole;
}
export declare namespace Kendra {
    /**
     * Represents an Amazon Kendra Index Edition.
     */
    enum Edition {
        DEVELOPER_EDITION = "DEVELOPER_EDITION",
        ENTERPRISE_EDITION = "ENTERPRISE_EDITION",
        GEN_AI_ENTERPRISE_EDITION = "GEN_AI_ENTERPRISE_EDITION"
    }
    /**
     * Represents an Amazon Kendra Index Field Type.
     */
    enum IndexFieldTypes {
        STRING = "STRING_VALUE",
        STRING_LIST = "STRING_LIST_VALUE",
        LONG = "LONG_VALUE",
        DATE = "DATE_VALUE"
    }
    /**
     * The different policies available to filter search results based on user context.
     */
    enum UserContextPolicy {
        /** All indexed content is searchable and displayable for all users.
         * If you want to filter search results on user context, you can use
         * the attribute filters of _user_id and _group_ids or you can provide
         * user and group information in UserContext . */
        ATTRIBUTE_FILTER = "ATTRIBUTE_FILTER",
        /**
         * Enables token-based user access control to filter search results on
         * user context. All documents with no access control and all documents
         * accessible to the user will be searchable and displayable.
         */
        USER_TOKEN = "USER_TOKEN"
    }
}
/******************************************************************************
 *                        PROPS FOR NEW CONSTRUCT
 *****************************************************************************/
/**
 * Properties for creating a GenAI Index.
 */
export interface KendraGenAiIndexProps {
    /**
     * The name of the index.
     * @default - A name is generated by CDK.
     */
    readonly name?: string;
    /**
     * The identifier of the AWS KMS customer managed key (CMK) to use
     * to encrypt data indexed by Amazon Kendra. Amazon Kendra doesn't support
     * asymmetric CMKs.
     * @default - AWS managed encryption key is used.
     */
    readonly kmsKey?: IKey;
    /**
     * The document capacity units. Every unit increases the baseline capacity by 20,000 documents.
     * E.g. `documentCapacityUnits: 1` means Baseline + 20,000 documents = 40,000 documents
     * @default 0 - baseline capacity of 20,000 documents
     */
    readonly documentCapacityUnits?: number;
    /**
     * The query capacity units. Every unit increases the baseline capacity by 0.1 QPS.
     * E.g. `queryCapacityUnits: 7` means Baseline + 0.1 QPS * 7 = 0.8 QPS
     * @default 0 - baseline capacity of 0.1 QPS
     */
    readonly queryCapacityUnits?: number;
}
/******************************************************************************
 *                      ATTRS FOR IMPORTED CONSTRUCT
 *****************************************************************************/
/**
 * Properties needed for importing an existing Kendra Index.
 */
export interface KendraGenAiIndexAttributes {
    /**
     * The Id of the index.
     * @example 'af04c7ea-22bc-46b7-a65e-6c21e604fc11'
     */
    readonly indexId: string;
    /**
     * An IAM role that gives your Amazon Kendra index permissions.
     */
    readonly role: iam.IRole;
}
/******************************************************************************
 *                              COMMON
 *****************************************************************************/
/**
 * Abstract base class for a Kendra GenAI index.
 * Contains methods and attributes valid for Kendra GenAI Indexes either created with CDK or imported.
 */
export declare abstract class KendraGenAiIndexBase extends Resource implements IKendraGenAiIndex {
    abstract readonly indexArn: string;
    abstract readonly indexId: string;
    abstract readonly role: iam.IRole;
}
/******************************************************************************
 *                        NEW CONSTRUCT DEFINITION
 *****************************************************************************/
/**
 * Class to create a Kendra GenAI Index with CDK.
 * @cloudformationResource AWS::Kendra::Index
 */
export declare class KendraGenAiIndex extends KendraGenAiIndexBase {
    /**
     * Import a guardrail given its attributes
     */
    static fromAttrs(scope: Construct, id: string, attrs: KendraGenAiIndexAttributes): IKendraGenAiIndex;
    readonly indexArn: string;
    readonly indexId: string;
    readonly role: iam.IRole;
    /**
     * The edition of the Gen AI index
     */
    readonly edition: Kendra.Edition;
    /**
     * The name of the Gen AI index
     */
    readonly name: string;
    /**
     * The AWS KMS key (CMK) used to encrypt data
     */
    readonly kmsKey?: IKey;
    /**
     * The document capacity units used for the Gen AI index
     */
    readonly documentCapacityUnits: number;
    /**
     * The query capacity units used for the Gen AI index
     */
    readonly queryCapacityUnits: number;
    /**
     * The L1 representation of the Kendra Index
     */
    private readonly _resource;
    constructor(scope: Construct, id: string, props: KendraGenAiIndexProps);
}
